#
# The "database".
#

#
# This code is part of the LWN git data miner.
#
# Copyright 2007 LWN.net
# Copyright 2007 Jonathan Corbet <corbet@lwn.net>
#
# This file may be distributed under the terms of the GNU General
# Public License, version 2.



class Hacker:
    def __init__ (self, name, id, empl, email):
        self.name = name
        self.id = id
        self.employer = empl
        self.email = email
        self.added = self.removed = 0
        self.patches = [ ]
        self.signoffs = [ ]

    def addpatch (self, patch):
        self.added += patch.added
        self.removed += patch.removed
        self.patches.append (patch)

    def addsob (self, patch):
        self.signoffs.append (patch)

HackersByName = { }
HackersByEmail = { }
HackersByID = { }
MaxID = 0

def StoreHacker (name, empl, email):
    global MaxID

    id = MaxID
    MaxID += 1
    h = Hacker (name, id, empl, email)
    HackersByName[name] = h
    HackersByEmail[email] = h
    HackersByID[id] = h
    return h

def LookupEmail (addr):
    try:
        return HackersByEmail[addr]
    except KeyError:
        return None

def LookupName (name):
    try:
        return HackersByName[name]
    except KeyError:
        return None

def LookupID (id):
    try:
        return HackersByID[id]
    except KeyError:
        return None

def AllHackers ():
    return HackersByID.values ()


#
# Employer info.
#
class Employer:
    def __init__ (self, name):
        self.name = name
        self.added = self.removed = self.count = self.changed = 0
        self.hackers = [ ]

    def AddCSet (self, patch):
        self.added += patch.added
        self.removed += patch.removed
        self.changed += max(patch.added, patch.removed)
        self.count += 1
        if patch.author not in self.hackers:
            self.hackers.append (patch.author)

Employers = { }

def LookupEmployer (name):
    try:
        return Employers[name]
    except KeyError:
        e = Employer (name)
        Employers[name] = e
        return e

def AllEmployers ():
    return Employers.values ()
